==> esp8266-0.3.0.crate: esp8266-0.3.0/src/gpio/gpio_status.rs <==
#[doc = "Register `GPIO_STATUS` reader"]
pub struct R(crate::R<GPIO_STATUS_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<GPIO_STATUS_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::convert::From<crate::R<GPIO_STATUS_SPEC>> for R {
    fn from(reader: crate::R<GPIO_STATUS_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `GPIO_STATUS` writer"]
pub struct W(crate::W<GPIO_STATUS_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<GPIO_STATUS_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl core::convert::From<crate::W<GPIO_STATUS_SPEC>> for W {
    fn from(writer: crate::W<GPIO_STATUS_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `GPIO_STATUS_INTERRUPT` reader - Interrupt enable register."]
pub struct GPIO_STATUS_INTERRUPT_R(crate::FieldReader<u16, u16>);
impl GPIO_STATUS_INTERRUPT_R {
    pub(crate) fn new(bits: u16) -> Self {
        GPIO_STATUS_INTERRUPT_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for GPIO_STATUS_INTERRUPT_R {
    type Target = crate::FieldReader<u16, u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `GPIO_STATUS_INTERRUPT` writer - Interrupt enable register."]
pub struct GPIO_STATUS_INTERRUPT_W<'a> {
    w: &'a mut W,
}
impl<'a> GPIO_STATUS_INTERRUPT_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u16) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xffff) | ((value as u32) & 0xffff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:15 - Interrupt enable register."]
    #[inline(always)]
    pub fn gpio_status_interrupt(&self) -> GPIO_STATUS_INTERRUPT_R {
        GPIO_STATUS_INTERRUPT_R::new((self.bits & 0xffff) as u16)
    }
}
impl W {
    #[doc = "Bits 0:15 - Interrupt enable register."]
    #[inline(always)]
    pub fn gpio_status_interrupt(&mut self) -> GPIO_STATUS_INTERRUPT_W {
        GPIO_STATUS_INTERRUPT_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "GPIO_STATUS\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [gpio_status](index.html) module"]
pub struct GPIO_STATUS_SPEC;
impl crate::RegisterSpec for GPIO_STATUS_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [gpio_status::R](R) reader structure"]
impl crate::Readable for GPIO_STATUS_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [gpio_status::W](W) writer structure"]
impl crate::Writable for GPIO_STATUS_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets GPIO_STATUS to value 0"]
impl crate::Resettable for GPIO_STATUS_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp8266-0.4.0.crate: esp8266-0.4.0/src/gpio/gpio_status.rs <==
#[doc = "Register `GPIO_STATUS` reader"]
pub struct R(crate::R<GPIO_STATUS_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<GPIO_STATUS_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<GPIO_STATUS_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<GPIO_STATUS_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `GPIO_STATUS` writer"]
pub struct W(crate::W<GPIO_STATUS_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<GPIO_STATUS_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<GPIO_STATUS_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<GPIO_STATUS_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `GPIO_STATUS_INTERRUPT` reader - Interrupt enable register."]
pub struct GPIO_STATUS_INTERRUPT_R(crate::FieldReader<u16, u16>);
impl GPIO_STATUS_INTERRUPT_R {
    #[inline(always)]
    pub(crate) fn new(bits: u16) -> Self {
        GPIO_STATUS_INTERRUPT_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for GPIO_STATUS_INTERRUPT_R {
    type Target = crate::FieldReader<u16, u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `GPIO_STATUS_INTERRUPT` writer - Interrupt enable register."]
pub struct GPIO_STATUS_INTERRUPT_W<'a> {
    w: &'a mut W,
}
impl<'a> GPIO_STATUS_INTERRUPT_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u16) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xffff) | (value as u32 & 0xffff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:15 - Interrupt enable register."]
    #[inline(always)]
    pub fn gpio_status_interrupt(&self) -> GPIO_STATUS_INTERRUPT_R {
        GPIO_STATUS_INTERRUPT_R::new((self.bits & 0xffff) as u16)
    }
}
impl W {
    #[doc = "Bits 0:15 - Interrupt enable register."]
    #[inline(always)]
    pub fn gpio_status_interrupt(&mut self) -> GPIO_STATUS_INTERRUPT_W {
        GPIO_STATUS_INTERRUPT_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "GPIO_STATUS\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [gpio_status](index.html) module"]
pub struct GPIO_STATUS_SPEC;
impl crate::RegisterSpec for GPIO_STATUS_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [gpio_status::R](R) reader structure"]
impl crate::Readable for GPIO_STATUS_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [gpio_status::W](W) writer structure"]
impl crate::Writable for GPIO_STATUS_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets GPIO_STATUS to value 0"]
impl crate::Resettable for GPIO_STATUS_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
